SDX package guide — sdx-common 0.7.1 documentation

# SDX package guide

# SDX-common

Common classes for SDX apps. Contains a single package:

> - sdx.common

## sdx.common

A common library for SDX apps. App projects declare their dependence on sdx-common which is deployed and installed via pip.

## Basic use

Assuming a Python 3.5 virtual environment at `~/py3.5`:

1. Run the unit tests:

       ~/py3.5/bin/python -m unittest discover sdx

2. Create a package for deployment:

       ~/py3.5/bin/python setup.py sdist

3. Install source package with pip:

       ~/py3.5/bin/pip install -U dist/sdx-common-x.y.z.tar.gz

4. Install extra dependencies for development and building documentation:

       ~/py3.5/bin/pip install .[dev,docbuild]

5. Build documentation pages:

       ~/py3.5/bin/sphinx-build sdx/common/doc sdx/common/doc/html

Contents:

- Changelog
  - Unreleased
  - 0.7.0
  - 0.6.0
- Setting Log Levels
- Survey accessors
- Processing functions
- Transformers
  - Transformer
  - ImageTransformer
  - PDFTransformer
- Formatters
- Tooling
  - Boilerplate
  - Command Line Interface

- Index
- Module Index
- Search Page